@@ -1,6 +1,7 @@
 """Main library for pylc3."""
 __author__ = """Brandon Whitehead"""
 __email__ = 'brandon.whitehead@gatech.edu'
-__version__ = '0.1.3'
+__version__ = '0.1.5'
 
-from . import core
\ No newline at end of file
+from .core import LC3State
+from .core import MemoryFillStrategy
\ No newline at end of file
